@@ -232,7 +232,7 @@ GetGCs(Widget w)
 /* CalculatedValues()
  *
  * does routine checks/computations that must be done after data changes
- * but won't hurt if accidently called
+ * but won't hurt if accidentally called
  *
  * These calculations were needed in SetValues.  They were in ResetList.
  * ResetList called ChangeSize, which made an XtGeometryRequest.  You
@@ -350,7 +350,7 @@ ChangeSize(Widget w, Dimension width, Dimension height)
 }
 
 /*	Function Name: Initialize
- *	Description: Function that initilizes the widget instance.
+ *	Description: Function that initializes the widget instance.
  *	Arguments: junk - NOT USED.
  *                 new  - the new widget.
  *	Returns: none
@@ -501,7 +501,7 @@ HighlightBackground(Widget w, int x, int y, GC gc)
 {
     ListWidget lw = (ListWidget) w;
 
-    /* easy to clip the rectangle by hand and probably alot faster than Xlib */
+    /* easy to clip the rectangle by hand and probably a lot faster than Xlib */
 
     Dimension width               = lw->list.col_width;
     Dimension height              = lw->list.row_height;
@@ -1121,7 +1121,7 @@ XawListUnhighlight(Widget w)
 /*	Function Name: XawListHighlight
  *	Description: Highlights the given item.
  *	Arguments: w - the list widget.
- *                 item - the item to hightlight.
+ *                 item - the item to highlight.
  *	Returns: none.
  */
 
