@@ -384,7 +384,7 @@ GetRequestInfo(XtWidgetGeometry * geo_struct, Boolean vert)
  *
  *                   1) size < max && size > min
  *                   2) skip adjust == FALSE
- *                   3) widget not its prefered height &&
+ *                   3) widget not its preferred height &&
  *                      this change will bring it closer &&
  *                      The user has not resized this pane.
  *
@@ -576,7 +576,7 @@ LoopAndRefigureChildren(PanedWidget pw, int paneindex, Direction dir, int *sizeu
  *      dir   - AnyPane.
  *
  *      If either of these is true then all panes may be resized and
- *      the choosing of panes procedes in reverse order starting with the
+ *      the choosing of panes proceeds in reverse order starting with the
  *      last child.
  */
 
@@ -1621,7 +1621,7 @@ ChangeManaged(Widget w)
 	       Pane pane = PaneInfo(*childP);
 	       if (HasGrip(*childP))
 		   PaneInfo(pane->grip)->position = pw->paned.num_panes;
-	       pane->position = pw->paned.num_panes; /*TEMPORY -CDP 3/89 */
+	       pane->position = pw->paned.num_panes; /*TEMPORARY -CDP 3/89 */
 	       pw->paned.num_panes++;
 	   }
 	   else
