@@ -90,7 +90,12 @@ in this Software without prior written authorization from the X Consortium.
  *
  *****************************************************/
 
-extern void XawVendorShellExtResize(Widget);
+/*
+ * From Vendor.c
+ */
+void XawVendorShellExtResize(Widget);
+void XawVendorStructureNotifyHandler(Widget, XtPointer, XEvent*, Boolean*);
+
 
 static XawIcTableList CurrentSharedIcTable(
     XawVendorShellExtPart* /* ve */
@@ -1373,7 +1378,7 @@ _XawImRealize(
     if ( !XtIsRealized( w ) || !XtIsVendorShell( w ) ) return;
     if ((ve = GetExtPart( (VendorShellWidget) w ))) {
 	XtAddEventHandler( w, (EventMask)StructureNotifyMask, FALSE,
-			  XawVendorShellExtResize, (XtPointer)NULL );
+			  XawVendorStructureNotifyHandler, (XtPointer)NULL );
 	AllCreateIC(ve);
     }
 }
